@@ -73,6 +73,7 @@ pub fn test_ignore_dir() {
     let output = build_command(vec!["-c", "-X", "dir_substring", "tests/test_dir2/"]);
     assert!(!output.contains("dir_substring"));
 }
+// Add test for multiple dirs - with -d 0 and maybe -d 1 check the
 
 #[test]
 pub fn test_with_bad_param() {
@@ -116,6 +117,15 @@ pub fn test_show_files_by_type() {
     assert!(output.contains("┌─┴ (total)"));
 }
 
+#[test]
+#[cfg(target_family = "unix")]
+pub fn test_show_files_only() {
+    let output = build_command(vec!["-c", "-F", "tests/test_dir"]);
+    assert!(output.contains("tests/test_dir/many/a_file"));
+    assert!(output.contains("tests/test_dir/many/hello_file"));
+    assert!(!output.contains("tests/test_dir/many "));
+}
+
 #[test]
 pub fn test_output_skip_total() {
     let output = build_command(vec![
@@ -127,6 +137,23 @@ pub fn test_output_skip_total() {
     assert!(!output.contains("(total)"));
 }
 
+#[test]
+pub fn test_output_screen_reader() {
+    let output = build_command(vec!["--screen-reader", "-c", "tests/test_dir/"]);
+    println!("{}", output);
+    assert!(output.contains("test_dir   0"));
+    assert!(output.contains("many       1"));
+    assert!(output.contains("hello_file 2"));
+    assert!(output.contains("a_file     2"));
+
+    // Verify no 'symbols' reported by screen reader
+    assert!(!output.contains("│"));
+
+    for block in ['█', '▓', '▒', '░'] {
+        assert!(!output.contains(block));
+    }
+}
+
 #[test]
 pub fn test_show_files_by_regex_match_lots() {
     // Check we can see '.rs' files in the tests directory
